==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/OCMID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour OCMID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="OCMID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OCM_VARID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OCM_DATESTAMP"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OCMID_Type", propOrder = {
    "ocm_VARID",
    "ocm_DATESTAMP"
})
public class OCMID_Type {

    @XmlElement(name = "OCM_VARID")
    protected long ocm_VARID;
    @XmlElement(name = "OCM_DATESTAMP", required = true)
    protected DATETIME ocm_DATESTAMP;

    /**
     * Obtient la valeur de la propriété ocm_VARID.
     * 
     */
    public long getOCM_VARID() {
        return ocm_VARID;
    }

    /**
     * Définit la valeur de la propriété ocm_VARID.
     * 
     */
    public void setOCM_VARID(long value) {
        this.ocm_VARID = value;
    }

    /**
     * Obtient la valeur de la propriété ocm_DATESTAMP.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getOCM_DATESTAMP() {
        return ocm_DATESTAMP;
    }

    /**
     * Définit la valeur de la propriété ocm_DATESTAMP.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setOCM_DATESTAMP(DATETIME value) {
        this.ocm_DATESTAMP = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/OCMID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for OCMID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OCMID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OCM_VARID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OCM_DATESTAMP"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OCMID_Type", propOrder = {
    "ocm_VARID",
    "ocm_DATESTAMP"
})
public class OCMID_Type {

    @XmlElement(name = "OCM_VARID")
    protected long ocm_VARID;
    @XmlElement(name = "OCM_DATESTAMP", required = true)
    protected DATETIME ocm_DATESTAMP;

    /**
     * Gets the value of the ocm_VARID property.
     * 
     */
    public long getOCM_VARID() {
        return ocm_VARID;
    }

    /**
     * Sets the value of the ocm_VARID property.
     * 
     */
    public void setOCM_VARID(long value) {
        this.ocm_VARID = value;
    }

    /**
     * Gets the value of the ocm_DATESTAMP property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getOCM_DATESTAMP() {
        return ocm_DATESTAMP;
    }

    /**
     * Sets the value of the ocm_DATESTAMP property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setOCM_DATESTAMP(DATETIME value) {
        this.ocm_DATESTAMP = value;
    }

}
